@@ -10,7 +10,7 @@ use URI::Encode qw( uri_encode );
 use POSIX qw( strftime );
 use Data::UUID;
 
-our $VERSION = '0.27';
+our $VERSION = '0.28';
 
 my $XMLer = Search::Tools::XML->new;
 
@@ -188,10 +188,13 @@ sub _build_entries {
             = $XMLer->start_tag( 'content', { type => 'application/xml' } );
         $micro .= $XMLer->perl_to_xml(
             $result,
-            {   tag   => 'fields',
-                attrs => { xmlns => 'http://dezi.org/sos/schema' },
+            {   root => {
+                    tag   => 'fields',
+                    attrs => { xmlns => 'http://dezi.org/sos/schema' },
+                },
+                escape       => 0,
+                strip_plural => 0
             },
-            0, 1,
         );
         $micro .= $XMLer->end_tag('content');
 
